@@ -75,7 +75,7 @@ for name in maintscripts:
             total_entries += len(removed)
 
 if total_entries == 1:
-    report_result('Remove %d obsolete maintscript entry.' % total_entries)
+    report_result('Remove an obsolete maintscript entry.')
 else:
     report_result('Remove %d obsolete maintscript entries in %d files.' %
                   (total_entries, len(ret)))
