@@ -1,13 +1,14 @@
 #!/usr/bin/python3
 
-from lintian_brush.fixer import fixed_lintian_tag, report_result
-
 import re
 import sys
+from typing import List
+
+from lintian_brush.fixer import LintianIssue, report_result
 
 
 def expand_tabs(line, tabwidth=8):
-    ret = []
+    ret: List[bytes] = []
     for i, c in enumerate(line):
         if line[i:i+1] == b'\t':
             # Round up to the next unit of tabwidth
@@ -18,7 +19,10 @@ def expand_tabs(line, tabwidth=8):
 
 
 def whitespace_prefix_length(line):
-    return len(re.match(b'^\\s*', line).group(0))
+    m = re.match(b'^\\s*', line)
+    if not m:
+        return 0
+    return len(m.group(0))
 
 
 def value_offset(line):
@@ -60,18 +64,20 @@ try:
         prev_value_offset = None
         for lineno, line in enumerate(f, start=2):
             if line.startswith(b'\t'):
-                for option in [
-                        b' \t' + line[1:], b' \t' + line[2:],
-                        b' ' * 8 + line[1:]]:
-                    if value_offset(option) == prev_value_offset:
-                        line = option
-                        break
-                else:
-                    line = b' \t' + line[1:]
-                tabs_replaced = True
-                fixed_lintian_tag(
+                issue = LintianIssue(
                     'source', 'tab-in-license-text',
                     info='debian/copyright (paragraph at line %d)' % lineno)
+                if issue.should_fix():
+                    for option in [
+                            b' \t' + line[1:], b' \t' + line[2:],
+                            b' ' * 8 + line[1:]]:
+                        if value_offset(option) == prev_value_offset:
+                            line = option
+                            break
+                    else:
+                        line = b' \t' + line[1:]
+                    tabs_replaced = True
+                    issue.report_fixed()
             if UNICODE_PARAGRAPH_SEPARATOR in line:
                 # Not quite the same thing, but close enough..
                 line = line.replace(
@@ -89,8 +95,8 @@ try:
 except FileNotFoundError:
     pass
 else:
-    with open('debian/copyright', 'wb') as f:
-        f.writelines(lines)
+    with open('debian/copyright', 'wb') as g:
+        g.writelines(lines)
 
 sys.stdout.write('debian/copyright: ')
 if tabs_replaced:
