@@ -1,13 +1,12 @@
 #!/usr/bin/python3
 
-from debmutate.control import ControlEditor
-from lintian_brush.fixer import report_result, LintianIssue
+from lintian_brush.fixer import control, report_result, LintianIssue
 
 binary_homepages = set()
 source_homepage = None
 
 
-with ControlEditor() as updater:
+with control as updater:
     source_homepage = updater.source.get('Homepage')
     for binary in updater.binaries:
         if 'Homepage' not in binary:
@@ -15,7 +14,7 @@ with ControlEditor() as updater:
         if source_homepage == binary['Homepage']:
             issue = LintianIssue('source', 'homepage-in-binary-package')
             # Source and binary both have a homepage field, but they're the
-            # same => drop the binary package Homepage field
+            # same ⇒ drop the binary package Homepage field
             if issue.should_fix():
                 issue.report_fixed()
                 del binary['Homepage']
