@@ -43,7 +43,7 @@ class LintianIssue(object):
     """Represents a lintian issue."""
 
     target: Tuple[str, Optional[str]]
-    info: Optional[Union[str, Tuple[str, ...]]]
+    info: Optional[str]
     tag: str
 
     def __init__(
@@ -54,19 +54,21 @@ class LintianIssue(object):
     ):
         if isinstance(target, (Deb822Paragraph, MutableMapping)):
             if "Source" in target:
-                target = ("source", target["Source"])
+                self.target = ("source", target["Source"])
             elif "Package" in target:
-                target = ("binary", target["Package"])
+                self.target = ("binary", target["Package"])
             else:
                 raise ValueError(
                     "unable to determine source/binary package from target"
                 )
         elif target == "source":
-            target = ("source", None)
+            self.target = ("source", None)
+        else:
+            self.target = target  # type: ignore
         if isinstance(info, tuple):
-            info = " ".join(info)
-        self.target = target  # type: ignore
-        self.info = info
+            self.info = " ".join(info)
+        else:
+            self.info = info
         self.tag = tag
 
     def override_exists(self):
@@ -244,3 +246,31 @@ else:
 
 def vendor() -> str:
     return get_vendor_name()
+
+
+def linenos_to_ranges(linenos):
+    ret = []
+    cur_range: List[int] = []
+
+    def finalize_range(r):
+        if len(r) == 1:
+            ret.append("%d" % r[0])
+        else:
+            ret.append("%d-%d" % (r[0], r[-1]))
+
+    for lineno in linenos:
+        if not cur_range or cur_range[-1] == lineno-1:
+            cur_range.append(lineno)
+        else:
+            finalize_range(cur_range)
+            cur_range = [lineno]
+    if cur_range:
+        finalize_range(cur_range)
+    return ret
+
+
+def shorten_path(path):
+    ps = path.split('/')
+    if ps[0] == 'debian':
+        ps[0] = 'd'
+    return '/'.join(ps)
