@@ -19,7 +19,7 @@
 
 import json
 import os
-from typing import Optional
+from typing import Optional, TextIO
 
 LINTIAN_DATA_PATH = '/usr/share/lintian/data'
 
@@ -39,7 +39,7 @@ def read_debhelper_lintian_data_file(f, sep):
         yield key, value
 
 
-def read_list_file(f, vendor):
+def read_list_file(f: TextIO, vendor: Optional[str] = None):
     for line in f:
         line = line.strip()
         if not line:
@@ -49,7 +49,8 @@ def read_list_file(f, vendor):
         if line.startswith('@'):
             cond, if_vendor, val = line.split(None, 2)
             if cond == '@if-vendor-is-not':
-                if if_vendor.lower() == vendor.lower():
+                if (if_vendor and vendor and
+                        if_vendor.lower() == vendor.lower()):
                     continue
                 line = val
             else:
@@ -88,7 +89,7 @@ def _read_test_fields(path, vendor):
 
     # Older versions of lintian listed fields with all lowercase.
     if all([x == x.lower() for x in fields]):
-        fields = set([_capitalize_field(x) for x in fields])
+        fields = [_capitalize_field(x) for x in fields]
     return fields
 
 
