@@ -30,12 +30,15 @@ __all__ = [
 ]
 
 from io import StringIO
+import os
+from typing import Dict, Any, List
 
 from iniparse.config import (
     ConfigNamespace,
     Undefined,
 )
 from iniparse.ini import (
+    LineType,
     LineContainer,
     SectionLine,
     OptionLine,
@@ -50,7 +53,6 @@ from iniparse.ini import (
 
 from debmutate.reformatting import Editor
 
-import os
 
 LIST_KEYS = [
     "Before",
@@ -67,8 +69,8 @@ LIST_KEYS = [
 
 
 class Section(ConfigNamespace):
-    _lines = None
-    _options = None
+    _lines: List[LineType] = None  # type: ignore
+    _options: Dict[str, Any] = None  # type: ignore
 
     def __init__(self, lineobj):
         self._lines = [lineobj]
@@ -219,8 +221,8 @@ class OptionList(object):
 
 
 class UnitFile(ConfigNamespace):
-    _data = None
-    _sections = None
+    _data: LineContainer = None
+    _sections: Dict[str, Section] = None
 
     def __init__(self, fp=None):
         self._data = LineContainer()
@@ -280,7 +282,7 @@ class UnitFile(ConfigNamespace):
         cur_option = None
         cur_section_name = None
         cur_option_name = None
-        pending_lines = []
+        pending_lines: List[LineType] = []
         try:
             fname = fp.name
         except AttributeError:
@@ -320,12 +322,12 @@ class UnitFile(ConfigNamespace):
 
             if isinstance(lineobj, OptionLine):
                 if pending_lines:
-                    cur_section.extend(pending_lines)
+                    cur_section.extend(pending_lines)  # type: ignore
                     pending_lines = []
                 cur_option = LineContainer(lineobj)
-                cur_section.add(cur_option)
+                cur_section.add(cur_option)  # type: ignore
                 cur_option_name = cur_option.name
-                optobj = self._sections[cur_section_name]
+                optobj = self._sections[cur_section_name]  # type: ignore
                 if cur_option_name in LIST_KEYS:
                     if not cur_option.value.split():
                         # Reset list.
