@@ -28,11 +28,15 @@ class VcsWatch(object):
     def __init__(self):
         self._conn = None
 
-    async def connect(self):
+    async def __aenter__(self):
         from .udd import connect_udd_mirror
-
         self._conn = await connect_udd_mirror()
 
+    async def __aexit__(self, exc_type, exc, tb):
+        if self._conn is None:
+            raise RuntimeError('not in context manager')
+        return await self._conn.__aexit__(exc_type, exc, tb)
+
     async def get_package(self, name):
         """Get the VCS information for a package.
 
